==> magento-module-custom-attribute-serializable-graph-ql-0.1.3.zip: Model/Resolver/Cart/Item/CustomAttributes.php <==
<?php
/************************************************************************
 *
 * ADOBE CONFIDENTIAL
 * ___________________
 *
 * Copyright 2024 Adobe
 * All Rights Reserved.
 *
 * NOTICE: All information contained herein is, and remains
 * the property of Adobe and its suppliers, if any. The intellectual
 * and technical concepts contained herein are proprietary to Adobe
 * and its suppliers and are protected by all applicable intellectual
 * property laws, including trade secret and copyright laws.
 * Dissemination of this information or reproduction of this material
 * is strictly forbidden unless prior written permission is obtained
 * from Adobe.
 * ************************************************************************
 */
declare(strict_types=1);

namespace Magento\CustomAttributeSerializableGraphQl\Model\Resolver\Cart\Item;

use Magento\CustomAttributeSerializableGraphQl\Model\CustomAttributesToOutputConverter;
use Magento\Framework\GraphQl\Config\Element\Field;
use Magento\Framework\GraphQl\Exception\GraphQlInputException;
use Magento\Framework\GraphQl\Query\Resolver\ContextInterface;
use Magento\Framework\GraphQl\Query\Resolver\Value;
use Magento\Framework\GraphQl\Query\ResolverInterface;
use Magento\Framework\GraphQl\Schema\Type\ResolveInfo;

/**
 * Resolver for custom attributes field of cart item
 */
class CustomAttributes implements ResolverInterface
{
    /**
     * @param CustomAttributesToOutputConverter $customAttributesToOutputConverter
     */
    public function __construct(
        private readonly CustomAttributesToOutputConverter $customAttributesToOutputConverter
    ) {
    }

    /**
     * Return information about custom attributes for cart item
     *
     * @param Field            $field
     * @param ContextInterface $context
     * @param ResolveInfo      $info
     * @param array|null       $value
     * @param array|null       $args
     *
     * @return array|Value|mixed
     * @throws GraphQlInputException
     * @SuppressWarnings(PHPMD.UnusedFormalParameter)
     */
    public function resolve(
        Field $field,
        $context,
        ResolveInfo $info,
        array $value = null,
        array $args = null
    ) {
        if (!isset($value['model'])) {
            throw new GraphQlInputException(__('The "model" value must be specified'));
        }

        $cartItem = $value['model'];

        return $this->customAttributesToOutputConverter->convert($cartItem->getCustomAttributes());
    }
}

==> magento-module-custom-attribute-serializable-graph-ql-0.5.0.zip: Model/Resolver/Cart/Item/CustomAttributes.php <==
<?php
/************************************************************************
 *
 * ADOBE CONFIDENTIAL
 * ___________________
 *
 * Copyright 2024 Adobe
 * All Rights Reserved.
 *
 * NOTICE: All information contained herein is, and remains
 * the property of Adobe and its suppliers, if any. The intellectual
 * and technical concepts contained herein are proprietary to Adobe
 * and its suppliers and are protected by all applicable intellectual
 * property laws, including trade secret and copyright laws.
 * Dissemination of this information or reproduction of this material
 * is strictly forbidden unless prior written permission is obtained
 * from Adobe.
 * ************************************************************************
 */
declare(strict_types=1);

namespace Magento\CustomAttributeSerializableGraphQl\Model\Resolver\Cart\Item;

use Magento\CustomAttributeSerializableGraphQl\Model\CustomAttributesToOutputConverter;
use Magento\Framework\GraphQl\Config\Element\Field;
use Magento\Framework\GraphQl\Exception\GraphQlInputException;
use Magento\Framework\GraphQl\Query\Resolver\ContextInterface;
use Magento\Framework\GraphQl\Query\Resolver\Value;
use Magento\Framework\GraphQl\Query\ResolverInterface;
use Magento\Framework\GraphQl\Schema\Type\ResolveInfo;

/**
 * Resolver for custom attributes field of cart item
 */
class CustomAttributes implements ResolverInterface
{
    /**
     * @param CustomAttributesToOutputConverter $customAttributesToOutputConverter
     */
    public function __construct(
        private readonly CustomAttributesToOutputConverter $customAttributesToOutputConverter
    ) {
    }

    /**
     * Return information about custom attributes for cart item
     *
     * @param Field            $field
     * @param ContextInterface $context
     * @param ResolveInfo      $info
     * @param array|null       $value
     * @param array|null       $args
     *
     * @return array|Value|mixed
     * @throws GraphQlInputException
     * @SuppressWarnings(PHPMD.UnusedFormalParameter)
     */
    public function resolve(
        Field $field,
        $context,
        ResolveInfo $info,
        ?array $value = null,
        ?array $args = null
    ) {
        if (!isset($value['model'])) {
            throw new GraphQlInputException(__('The "model" value must be specified'));
        }

        $cartItem = $value['model'];

        return $this->customAttributesToOutputConverter->convert($cartItem->getCustomAttributes());
    }
}
